@@ -48,7 +48,7 @@ sub new
     return $self;
 }
 
-=item Net::AS2::Message->create_error_message($message_id, $async_url, $should_mdn_sign, $status_text, $plain_text)
+=item Net::AS2::Message->create_error_message($message_id, $async_url, $should_mdn_sign, $mic, $content, $mic_alg)
 
 Create a new AS2 'error' message.
 
@@ -62,7 +62,7 @@ sub create_error_message
     return $self;
 }
 
-=item Net::AS2::Message->create_failure_message($message_id, $async_url, $should_mdn_sign, $status_text, $plain_text)
+=item Net::AS2::Message->create_failure_message($message_id, $async_url, $should_mdn_sign, $mic, $content, $mic_alg)
 
 Create a new AS2 'failure' message.
 
@@ -103,7 +103,7 @@ sub create_from_serialized_state
 {
     my ($class, $state) = @_;
 
-    my ($version, $status, $message_id, $mic, $mic_alg, $async_url, $should_mdn_sign, $status_text, $plain_text, $filename)
+    my ($version, $status, $message_id, $mic, $mic_alg, $async_url, $should_mdn_sign, $status_text, $plain_text)
         = split(/\n/, $state);
     croak "Net::AS2::Message state version is not supported"
         unless defined $version && $version eq 'v1' && defined $plain_text;
@@ -115,14 +115,13 @@ sub create_from_serialized_state
             $status eq '-1' ? ( error => 1 ) :
             ( failure => 1 )
         ),
-        message_id      => $message_id,
-        mic             => $mic,
-        mic_alg         => $mic_alg,
-        status_text     => $status_text,
+        message_id => $message_id,
+        mic => $mic,
+        mic_alg => $mic_alg,
+        status_text => $status_text,
         should_mdn_sign => $should_mdn_sign,
-        plain_text      => $plain_text,
-        async_url       => $async_url,
-        filename        => $filename,
+        plain_text => $plain_text,
+        async_url => $async_url
     };
     bless ($self, $class);
 
@@ -262,13 +261,12 @@ sub serialized_state {
         'v1',
         $self->is_success ? 1 : $self->is_error ? -1 : -2,
         $self->{message_id},
-        $self->{mic}             // '',
-        $self->{mic_alg}         // 'sha1',
-        $self->{async_url}       // '',
+        $self->{mic} // '',
+        $self->{mic_alg} // 'sha1',
+        $self->{async_url} // '',
         $self->{should_mdn_sign} // '',
-        $self->{status_text}     // '',
-        $self->{plain_text}      // '',
-        $self->{filename}        // '',
+        $self->{status_text} // '',
+        $self->{plain_text} // ''
     );
 }
 
